@@ -47,7 +47,7 @@ class TodoyPage(QWidget):
          self.resize(800,350)
 	 self.openImage(self.parent.conf.bkgrnd)
 	 self.openPixmap(self.parent.conf.bkgrnd)
-	 self.pen=QPen(Qt.black, self.parent.conf.defaultpen_size , Qt.SolidLine)
+	 self.pen=QPen(Qt.black, 4, Qt.SolidLine)
 	 self.p1 = QPoint(-1, -1)
 	 self.p2 = QPoint(-1, -1)
          self.date=strftime("%Y%m%d",gmtime())
@@ -95,7 +95,6 @@ class TodoyPage(QWidget):
 	infos=("Q: Quit, C: Clear, B: Blue, R: Red, G: Green, K: Black, Z: Undo.")
 	if self.inputmode=="sketch":p.drawText(20,90, infos)
 	pen=self.pen#QPen()
-	pen.setWidth(self.parent.conf.defaultpen_size)
 	self.draftPen=QPen()
 	#color = QColor(Qt.black)
 	#pen.setColor(color)
@@ -216,7 +215,7 @@ class TodoyPage(QWidget):
    def paintAuto(self, painter):
 	from math import atan, degrees
     	if (self.p2.x() != -1): 
-		orig=QPoint(400,240)
+		orig=QPoint(400,175)
 		self.orig=orig
 		pm=QPoint((self.p1.x()+self.p2.x())/2,(self.p1.y()+self.p2.y())/2)
 		#painter.drawLine(orig, self.p1)
@@ -226,6 +225,7 @@ class TodoyPage(QWidget):
 
 
 		painter.setFont(self.parent.conf.font)#QFont("Arial", 8))
+		#print self.parent.conf.font##############################################################debugline
 		painter.drawText(pm, self.text)
 		radi=self.getRadi()
 		if radi<self.parent.conf.g_rad_inner:
@@ -245,7 +245,7 @@ class TodoyPage(QWidget):
 			self.angles_time(self.parent.conf.g_scale_middle)
 		else:
 				self.angles_time(self.parent.conf.g_scale_outer)
-		rect=QRect(0,0,800,480)#orig,self.p2)
+		rect=QRect(0,0,800,350)#orig,self.p2)
 
 		painter.save()
 		painter.setBrush(Qt.green)
